---
slug: /collection-overview-of-api
---

# Manage collections

In pyseekdb, a collection is a set similar to a table in a database. You can create, query, and delete collections.

The following API interfaces are supported for managing collections.

| API interface | Description | Documentation |
|---|---|---|
| `create_collection()` | Creates a collection. | [Documentation](100.create-collection-of-api.md) |
| `get_collection()` | Gets a specified collection. |[Documentation](200.get-collection-of-api.md)|
| `get_or_create_collection()` | Creates or queries a collection. If the collection does not exist in the database, it is created. If the collection exists, the corresponding result is obtained. |[Documentation](250.get-or-create-collection-of-api.md)|
| `list_collections()`  | Gets the collection list of a database.  |[Documentation](300.list-collection-of-api.md)|
| `count_collection()`  | Counts the number of collections in a database  |[Documentation](350.count-collection-of-api.md)|
| `delete_collection()`  | Deletes a specified collection.|[Documentation](400.delete-collection-of-api.md)|
